pub struct AddMemoryRelation {
pub memory_id: String,
pub relation: String,
pub direction: GraphDirection,
pub metadata: HashMap<String, Value>,
}Expand description
Optional relation spec used by add-memory request.
Fields
memory_id: StringExisting memory id to connect with the newly added memory.
relation: Stringdirection: GraphDirectionEdge direction relative to the newly added memory node.
outbound: new -> memory_id; inbound: memory_id -> new; both: write both edges.
metadata: HashMap<String, Value>Trait Implementations
Sourceimpl Clone for AddMemoryRelation
impl Clone for AddMemoryRelation
Sourcefn clone(&self) -> AddMemoryRelation
fn clone(&self) -> AddMemoryRelation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddMemoryRelation
impl Debug for AddMemoryRelation
Sourceimpl<'de> Deserialize<'de> for AddMemoryRelation
impl<'de> Deserialize<'de> for AddMemoryRelation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more